@@ -64,8 +64,8 @@ class Query:
 
     def run_query(self, tool_name, tool_version, input_prefix_mapping,
                   output_type, tool_args=None, database_name=None, database_version=None,
-                  custom_database_path=None, output_name="output", input_files=None,
-                  output_path=None, thread_statuses=None):
+                  custom_database_path=None, output_name="output", output_primary_name=None,
+                  input_files=None, output_path=None, thread_statuses=None):
         """Executes a query to the Toolchest API.
 
         :param tool_name: Tool to be used.
@@ -76,6 +76,7 @@ class Query:
         :param custom_database_path: Path (S3 URI) to a custom database.
         :param input_prefix_mapping: Mapping of input filepaths to associated prefix tags (e.g., "-1")
         :param output_name: (optional) Internal name of file outputted by the tool.
+        :param output_primary_name: (optional) basename of the primary output (e.g. "sample.fastq").
         :param input_files: List of paths to be passed in as input.
         :param output_path: Path (client-side) where the output file will be downloaded.
         :param output_type: Type (e.g. GZ_TAR) of the output file
@@ -93,6 +94,7 @@ class Query:
             database_version=database_version,
             custom_database_path=custom_database_path,
             output_name=output_name,
+            output_primary_name=output_primary_name,
             tool_name=tool_name,
             tool_version=tool_version,
             tool_args=tool_args,
@@ -139,7 +141,8 @@ class Query:
 
     def _send_initial_request(self, tool_name, tool_version, tool_args,
                               database_name, database_version, custom_database_path,
-                              output_name, compress_output, output_file_path):
+                              output_name, output_primary_name, output_file_path,
+                              compress_output):
         """Sends the initial request to the Toolchest API to create the query.
 
         Returns the response from the POST request.
@@ -152,6 +155,7 @@ class Query:
             "database_name": database_name,
             "database_version": database_version,
             "output_file_name": output_name,
+            "output_file_primary_name": output_primary_name,
             "tool_name": tool_name,
             "tool_version": tool_version,
             "output_file_path": output_file_path,
